@@ -1,11 +1,7 @@
 import os
 import shutil
-import sys
-import argparse
-import tempfile
 import pathlib
 import shutil
-import json
 import pathlib
 import importlib
 import subprocess
@@ -34,14 +30,12 @@ def _get_numpy_tools(filename):
 
 
 @click.command()
-@click.option(
-    "-t", "--token",
-    help="GitHub access token",
+@click.argument(
+    "token",
     required=True
 )
-@click.option(
-    "--revision-range",
-    help="<revision>..<revision>",
+@click.argument(
+    "revision-range",
     required=True
 )
 @click.pass_context
@@ -101,7 +95,7 @@ def changelog(ctx, token, revision_range):
 )
 @click.argument("meson_args", nargs=-1)
 @click.pass_context
-def build(ctx, meson_args, with_scipy_openblas, jobs=None, clean=False, verbose=False, quiet=False):
+def build(ctx, meson_args, with_scipy_openblas, jobs=None, clean=False, verbose=False, quiet=False, *args, **kwargs):
     """🔧 Build package with Meson/ninja and install
 
     MESON_ARGS are passed through e.g.:
@@ -138,11 +132,13 @@ def build(ctx, meson_args, with_scipy_openblas, jobs=None, clean=False, verbose=
 @click.option(
     '--jobs', '-j',
     metavar='N_JOBS',
-    default="auto",
-    help="Number of parallel build jobs"
+    # Avoids pydata_sphinx_theme extension warning from default="auto".
+    default="1",
+    help=("Number of parallel build jobs."
+          "Can be set to `auto` to use all cores.")
 )
 @click.pass_context
-def docs(ctx, sphinx_target, clean, first_build, jobs):
+def docs(ctx, sphinx_target, clean, first_build, jobs, *args, **kwargs):
     """📖 Build Sphinx documentation
 
     By default, SPHINXOPTS="-W", raising errors on warnings.
@@ -164,6 +160,15 @@ def docs(ctx, sphinx_target, clean, first_build, jobs):
 
     """
     meson.docs.ignore_unknown_options = True
+
+    # Run towncrier without staging anything for commit. This is the way to get
+    # release notes snippets included in a local doc build.
+    cmd = ['towncrier', 'build', '--version', '2.x.y', '--keep', '--draft']
+    p = subprocess.run(cmd, check=True, capture_output=True, text=True)
+    outfile = curdir.parent / 'doc' / 'source' / 'release' / 'notes-towncrier.rst'
+    with open(outfile, 'w') as f:
+        f.write(p.stdout)
+
     ctx.forward(meson.docs)
 
 
@@ -202,7 +207,7 @@ Which tests to run. Can be a module, function, class, or method:
     '--verbose', '-v', is_flag=True, default=False
 )
 @click.pass_context
-def test(ctx, pytest_args, markexpr, n_jobs, tests, verbose):
+def test(ctx, pytest_args, markexpr, n_jobs, tests, verbose, *args, **kwargs):
     """🔧 Run tests
 
     PYTEST_ARGS are passed through directly to pytest, e.g.:
@@ -357,7 +362,7 @@ def lint(ctx, branch, uncommitted):
         linter = _get_numpy_tools(pathlib.Path('linter.py'))
     except ModuleNotFoundError as e:
         raise click.ClickException(
-            f"{e.msg}. Install using linter_requirements.txt"
+            f"{e.msg}. Install using requirements/linter_requirements.txt"
         )
 
     linter.DiffLinter(branch).run_lint(uncommitted)
@@ -483,7 +488,7 @@ def bench(ctx, tests, compare, verbose, quick, commits):
 })
 @click.argument("python_args", metavar='', nargs=-1)
 @click.pass_context
-def python(ctx, python_args):
+def python(ctx, python_args, *args, **kwargs):
     """🐍 Launch Python shell with PYTHONPATH set
 
     OPTIONS are passed through directly to Python, e.g.:
@@ -567,7 +572,9 @@ def _config_openblas(blas_variant):
             fid.write(f"import {module_name}\n")
         os.makedirs(openblas_dir, exist_ok=True)
         with open(pkg_config_fname, "wt", encoding="utf8") as fid:
-            fid.write(openblas.get_pkg_config().replace("\\", "/"))
+            fid.write(
+                openblas.get_pkg_config(use_preloading=True)
+            )
 
 
 @click.command()
@@ -612,16 +619,10 @@ def notes(ctx, version_override):
     )
     # towncrier build --version 2.1 --yes
     cmd = ["towncrier", "build", "--version", version, "--yes"]
-    try:
-        p = util.run(
-                cmd=cmd,
-                sys_exit=False,
-                output=True,
-                encoding="utf-8"
-            )
-    except subprocess.SubprocessError as e:
+    p = util.run(cmd=cmd, sys_exit=False, output=True, encoding="utf-8")
+    if p.returncode != 0:
         raise click.ClickException(
-            f"`towncrier` failed returned {e.returncode} with error `{e.stderr}`"
+            f"`towncrier` failed returned {p.returncode} with error `{p.stderr}`"
         )
 
     output_path = project_config['tool.towncrier.filename'].format(version=version)
