@@ -38,7 +38,7 @@ from paver.easy import Bunch, options, task, sh
 #-----------------------------------
 
 # Path to the release notes
-RELEASE_NOTES = 'doc/source/release/1.26.2-notes.rst'
+RELEASE_NOTES = 'doc/source/release/2.0.0-notes.rst'
 
 
 #-------------------------------------------------------
@@ -50,70 +50,6 @@ options(installers=Bunch(releasedir="release",
                          installersdir=os.path.join("release", "installers")),)
 
 
-#------------------------
-# Get the release version
-#------------------------
-
-sys.path.insert(0, os.path.dirname(__file__))
-try:
-    from setup import FULLVERSION
-finally:
-    sys.path.pop(0)
-
-
-#--------------------------
-# Source distribution stuff
-#--------------------------
-def tarball_name(ftype='gztar'):
-    """Generate source distribution name
-
-    Parameters
-    ----------
-    ftype : {'zip', 'gztar'}
-        Type of archive, default is 'gztar'.
-
-    """
-    root = f'numpy-{FULLVERSION}'
-    if ftype == 'gztar':
-        return root + '.tar.gz'
-    elif ftype == 'zip':
-        return root + '.zip'
-    raise ValueError(f"Unknown type {type}")
-
-
-@task
-def sdist(options):
-    """Make source distributions.
-
-    Parameters
-    ----------
-    options :
-        Set by ``task`` decorator.
-
-    """
-    # First clean the repo and update submodules (for up-to-date doc html theme
-    # and Sphinx extensions)
-    sh('git clean -xdf')
-    sh('git submodule init')
-    sh('git submodule update')
-
-    # To be sure to bypass paver when building sdist... paver + numpy.distutils
-    # do not play well together.
-    # Cython is run over all Cython files in setup.py, so generated C files
-    # will be included.
-    sh('python3 setup.py sdist --formats=gztar,zip')
-
-    # Copy the superpack into installers dir
-    idirs = options.installers.installersdir
-    if not os.path.exists(idirs):
-        os.makedirs(idirs)
-
-    for ftype in ['gztar', 'zip']:
-        source = os.path.join('dist', tarball_name(ftype))
-        target = os.path.join(idirs, tarball_name(ftype))
-        shutil.copy(source, target)
-
-
 #-------------
 # README stuff
 #-------------
